@@ -1,4 +1,4 @@
-from poisson_approval.constants.constants import *
+from poisson_approval.constants.basic_constants import *
 from poisson_approval.strategies.StrategyThreshold import StrategyThreshold
 from poisson_approval.utils.DictPrintingInOrderIgnoringZeros import DictPrintingInOrderIgnoringZeros
 from poisson_approval.utils.UtilBallots import ballot_one, ballot_two, ballot_one_two, ballot_one_three
@@ -12,6 +12,13 @@ class StrategyOrdinal(StrategyThreshold):
     d_ranking_ballot : dict
         Keys are rankings and values are ballots, e.g. ``'abc': 'ab'``. A
         ballot can be ``''`` if the behavior of these voters is not specified in the strategy.
+    d_weak_order_ballot : dict
+        Key: weak order. Value: strategy. A strategy can be a valid ballot, ``SPLIT`` or ``''`` if the behavior
+        of these voters is not specified in the strategy. This is useful in two cases only: for "haters"
+        (e.g. ``'a~b>c'``) in Plurality, and for "lovers" (e.g. ``'a>b~c'``) in Anti-Plurality.
+        In all other cases, voters with a weak order have a dominant strategy and they automatically use it.
+        About ``'SPLIT'``: for example, in Plurality, ``'a~b>c': SPLIT`` means that half of voters with weak order
+        `abc` cast a ballot for `a`, and the other half for `b`.
     profile : Profile, optional
         The "context" in which the strategy is used.
     voting_rule : str
@@ -35,7 +42,7 @@ class StrategyOrdinal(StrategyThreshold):
         1
     """
 
-    def __init__(self, d_ranking_ballot, profile=None, voting_rule=None):
+    def __init__(self, d_ranking_ballot, d_weak_order_ballot=None, profile=None, voting_rule=None):
         """
             >>> strategy = StrategyOrdinal({'abc': 'non_existing_ballot'})
             Traceback (most recent call last):
@@ -60,7 +67,8 @@ class StrategyOrdinal(StrategyThreshold):
             else:
                 raise ValueError('Unknown strategy: ' + ballot)
         # Call parent class
-        super().__init__(d=d_ranking_threshold, profile=profile, voting_rule=voting_rule)
+        super().__init__(d=d_ranking_threshold, d_weak_order_ballot=d_weak_order_ballot,
+                         profile=profile, voting_rule=voting_rule)
 
     def __eq__(self, other):
         """Equality test.
@@ -82,14 +90,25 @@ class StrategyOrdinal(StrategyThreshold):
         """
         return (isinstance(other, StrategyOrdinal)
                 and self.d_ranking_ballot == other.d_ranking_ballot
+                and self.d_weak_order_ballot == other.d_weak_order_ballot
                 and self.voting_rule == other.voting_rule)
 
     def __repr__(self):
+        """
+        Examples
+        --------
+            >>> strategy = StrategyOrdinal({'abc': 'a'}, d_weak_order_ballot={'a~b>c': 'a'}, voting_rule=PLURALITY)
+            >>> repr(strategy)
+            "StrategyOrdinal({'abc': 'a'}, d_weak_order_ballot={'a~b>c': 'a'}, voting_rule='Plurality')"
+        """
         arguments = repr(self.d_ranking_ballot)
+        arguments_weak_orders = repr(self.d_weak_order_ballot)
+        if len(arguments_weak_orders) > 2:
+            arguments += ', d_weak_order_ballot=' + arguments_weak_orders
         if self.voting_rule != APPROVAL:
             arguments += ', voting_rule=%r' % self.voting_rule
         return 'StrategyOrdinal(%s)' % arguments
 
-    def _repr_pretty_(self, p, cycle):  # pragma: no cover
+    def _repr_pretty_(self, p, cycle):  # pragma: no cover - Only for notebooks
         # https://stackoverflow.com/questions/41453624/tell-ipython-to-use-an-objects-str-instead-of-repr-for-output
         p.text(str(self) if not cycle else '...')
