@@ -1,4 +1,4 @@
-from poisson_approval.constants.constants import *
+from poisson_approval.constants.basic_constants import *
 from poisson_approval.strategies.StrategyTwelve import StrategyTwelve
 from poisson_approval.utils.DictPrintingInOrderIgnoringZeros import DictPrintingInOrderIgnoringZeros
 from poisson_approval.utils.DictPrintingInOrderIgnoringNone import DictPrintingInOrderIgnoringNone
@@ -19,13 +19,20 @@ class StrategyThreshold(StrategyTwelve):
       `a` (they behave as if the pivot `ab` was very likely); and a ratio 0.8 are pessimistic, they vote for `ab`
       (they behave as if the pivot `bc` was very likely).
 
-    For a given ranking, the threshold and / or the ratio may be None, which means that they are not specified for
+    For a given ranking, the threshold and/or the ratio may be None, which means that they are not specified for
     this strategy.
 
     Parameters
     ----------
     d : dict
         Cf. examples below for the different types of input syntax.
+    d_weak_order_ballot : dict
+        Key: weak order. Value: strategy. A strategy can be a valid ballot, ``SPLIT`` or ``''`` if the behavior
+        of these voters is not specified in the strategy. This is useful in two cases only: for "haters"
+        (e.g. ``'a~b>c'``) in Plurality, and for "lovers" (e.g. ``'a>b~c'``) in Anti-Plurality.
+        In all other cases, voters with a weak order have a dominant strategy and they automatically use it.
+        About ``'SPLIT'``: for example, in Plurality, ``'a~b>c': SPLIT`` means that half of voters with weak order
+        `abc` cast a ballot for `a`, and the other half for `b`.
     ratio_optimistic : Number
         Cf. examples below for the different types of input syntax.
     profile : Profile, optional
@@ -77,7 +84,7 @@ class StrategyThreshold(StrategyTwelve):
     case.
     """
 
-    def __init__(self, d, ratio_optimistic=None, profile=None, voting_rule=None):
+    def __init__(self, d, d_weak_order_ballot=None, ratio_optimistic=None, profile=None, voting_rule=None):
         voting_rule = self._get_voting_rule_(profile, voting_rule)
         # Prepare the dictionaries of thresholds and ratios
         self.d_ranking_threshold = DictPrintingInOrderIgnoringNone({ranking: None for ranking in RANKINGS})
@@ -110,7 +117,8 @@ class StrategyThreshold(StrategyTwelve):
             else:
                 d_ranking_ballot[ranking] = UTILITY_DEPENDENT
         # Call parent class
-        super().__init__(d_ranking_ballot=d_ranking_ballot, profile=profile, voting_rule=voting_rule)
+        super().__init__(d_ranking_ballot=d_ranking_ballot, d_weak_order_ballot=d_weak_order_ballot,
+                         profile=profile, voting_rule=voting_rule)
 
     @cached_property
     def d_ranking_t_threshold_ratio_optimistic(self):
@@ -144,33 +152,57 @@ class StrategyThreshold(StrategyTwelve):
         return (isinstance(other, StrategyThreshold)
                 and self.d_ranking_threshold == other.d_ranking_threshold
                 and self.d_ranking_ratio_optimistic == other.d_ranking_ratio_optimistic
+                and self.d_weak_order_ballot == other.d_weak_order_ballot
                 and self.voting_rule == other.voting_rule)
 
     def __repr__(self):
+        """
+        Examples
+        --------
+            >>> strategy = StrategyThreshold({'abc': (0.4, 0.2)}, d_weak_order_ballot={'a~b>c': 'a'},
+            ...                              voting_rule=PLURALITY)
+            >>> repr(strategy)
+            "StrategyThreshold({'abc': (0.4, 0.2)}, d_weak_order_ballot={'a~b>c': 'a'}, voting_rule='Plurality')"
+        """
         d = DictPrintingInOrderIgnoringNone({
             k: t[0] if t[1] is None else t
             for k, t in self.d_ranking_t_threshold_ratio_optimistic.items()})
         arguments = repr(d)
+        arguments_weak_orders = repr(self.d_weak_order_ballot)
+        if len(arguments_weak_orders) > 2:
+            arguments += ', d_weak_order_ballot=' + arguments_weak_orders
         if self.voting_rule != APPROVAL:
             arguments += ', voting_rule=%r' % self.voting_rule
         return 'StrategyThreshold(%s)' % arguments
 
     def __str__(self):
+        """
+        Examples
+        --------
+            >>> strategy = StrategyThreshold({'abc': (0.4, 0.2)}, d_weak_order_ballot={'a~b>c': 'a'},
+            ...                              voting_rule=PLURALITY)
+            >>> str(strategy)
+            '<abc: utility-dependent (0.4, 0.2), a~b>c: a> (Plurality)'
+        """
         def t_threshold_ratio_to_string(t):
             return str(t[0]) if t[1] is None else '%s, %s' % t
 
-        result = '<' + ', '.join([
+        arguments = ', '.join([
             '%s: %s' % (ranking, self.d_ranking_ballot[ranking])
             + (' (%s)' % t_threshold_ratio_to_string(self.d_ranking_t_threshold_ratio_optimistic[ranking])
                if self.d_ranking_ballot[ranking] == UTILITY_DEPENDENT else '')
             for ranking in sorted(self.d_ranking_ballot) if self.d_ranking_ballot[ranking]
-        ]) + '>'
+        ])
+        arguments_weak_orders = str(self.d_weak_order_ballot)[1:-1]
+        if len(arguments_weak_orders) > 0:
+            arguments += ', ' + arguments_weak_orders
+        result = '<%s>' % arguments
         if self.profile is not None:
             result += ' ==> ' + str(self.winners)
         if self.voting_rule != APPROVAL:
             result += ' (%s)' % self.voting_rule
         return result
 
-    def _repr_pretty_(self, p, cycle):  # pragma: no cover
+    def _repr_pretty_(self, p, cycle):  # pragma: no cover - Only for notebooks
         # https://stackoverflow.com/questions/41453624/tell-ipython-to-use-an-objects-str-instead-of-repr-for-output
         p.text(str(self) if not cycle else '...')
