@@ -1,4 +1,7 @@
-class DictPrintingInOrder(dict):
+from poisson_approval.utils.SuperclassMeta import SuperclassMeta
+
+
+class DictPrintingInOrder(dict, metaclass=SuperclassMeta):
     """A dictionary that prints in the order of the keys.
 
     Examples
@@ -20,6 +23,6 @@ class DictPrintingInOrder(dict):
              "%s: %s" % (key, self[key]) for key in sorted(self)
         ]) + "}"
 
-    def _repr_pretty_(self, p, cycle):  # pragma: no cover
+    def _repr_pretty_(self, p, cycle):  # pragma: no cover - Only for notebooks
         # https://stackoverflow.com/questions/41453624/tell-ipython-to-use-an-objects-str-instead-of-repr-for-output
         p.text(str(self) if not cycle else '...')
