@@ -60,7 +60,7 @@ def test_best_response_anti_plurality():
         pivot_ki_easy_or_tight = False
         pivot_jk_easy_or_tight = False
         pivot_kj_easy_or_tight = False
-        threshold_utility = 1
+        utility_threshold = 1
         justification = Anti-plurality analysis
         ballot = ac
     """
@@ -76,5 +76,5 @@ def test_best_response_is_ij():
 def test_best_response_is_utility_dependent():
     tau = TauVector({'ab': Fraction(7, 15), 'ac': Fraction(1, 15), 'bc': Fraction(7, 15)}, voting_rule=ANTI_PLURALITY)
     best_response = BestResponseAntiPlurality(tau, 'abc')
-    assert best_response.threshold_utility == Fraction(1, 2)
+    assert best_response.utility_threshold == Fraction(1, 2)
     assert best_response.ballot == UTILITY_DEPENDENT
